======================
EasyLink Documentation
======================

.. todo::

    - Summary
    - Strengthen quickstart examples

EasyLink is a framework for ...

Quickstart
==========

.. include:: ../../README.rst
   :start-after: .. _python_support:
   :end-before: .. _end_python_support:

.. include:: ../../README.rst 
   :start-after: .. _installation:
   :end-before: .. _end_installation:

.. include:: ../../src/easylink/cli.py
   :start-after: .. _example_cli:
   :end-before: .. _end_example_cli:

.. toctree::
   :maxdepth: 2

   user_guide/index
   concepts/index
   api_reference/index
   glossary
